LinkablePython

Trait LinkablePython 

pub trait LinkablePython {
    // Required methods
    fn write_files(&self, dest_dir: &Path, target_triple: &str) -> Result<()>;
    fn linking_annotations(
        &self,
        dest_dir: &Path,
        alias: bool,
        target_triple: &str,
    ) -> Result<Vec<LinkingAnnotation>>;
}
Represents a linkable target defining a Python implementation.

Required Methods

fn write_files(&self, dest_dir: &Path, target_triple: &str) -> Result<()>

Write any files that need to exist to support linking.

Files will be written to the directory specified.

fn linking_annotations( &self, dest_dir: &Path, alias: bool, target_triple: &str, ) -> Result<Vec<LinkingAnnotation>>

Obtain linker annotations needed to link this libpython.

dest_dir will be the directory where any files written by write_files() will be located.

alias denotes whether to alias the library name to pythonXY.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors